@@ -13,11 +13,12 @@
 # language governing permissions and limitations under the License.
 import os
 
-from awscli.testutils import BaseAWSCommandParamsTest
+from awscli.testutils import BaseAWSCommandParamsTest, skip_if_windows
 from awscli.testutils import capture_input
 from awscli.testutils import mock 
 from awscli.compat import BytesIO
 from tests.functional.s3 import BaseS3TransferCommandTest
+from tests.functional.s3.test_sync_command import TestSyncCaseConflict
 from tests import requires_crt
 
 
@@ -1313,3 +1314,55 @@ class TestAccesspointCPCommand(BaseCPCommandTest):
                 self.put_object_request(mrap_arn, 'mykey')
             ]
         )
+
+
+class TestCpRecursiveCaseConflict(TestSyncCaseConflict):
+    prefix = 's3 cp --recursive '
+
+    def test_ignore_by_default(self):
+        self.files.create_file(self.lower_key, 'mycontent')
+        # Note there's no --case-conflict param.
+        cmd = f"{self.prefix} s3://bucket {self.files.rootdir}"
+        self.parsed_responses = [
+            self.list_objects_response([self.upper_key]),
+            self.get_object_response(),
+        ]
+        # Expect success, so not error mode.
+        _, stderr, _ = self.run_cmd(cmd, expected_rc=0)
+        # No warnings in stderr, so not warn or skip mode.
+        assert not stderr
+
+
+class TestS3ExpressCpRecursive(BaseCPCommandTest):
+    prefix = 's3 cp --recursive '
+
+    def test_s3_express_error_raises_exception(self):
+        cmd = (
+            f"{self.prefix} s3://bucket--usw2-az1--x-s3 {self.files.rootdir} "
+            "--case-conflict error"
+        )
+        _, stderr, _ = self.run_cmd(cmd, expected_rc=255)
+        assert "`error` is not a valid value" in stderr
+
+    def test_s3_express_skip_raises_exception(self):
+        cmd = (
+            f"{self.prefix} s3://bucket--usw2-az1--x-s3 {self.files.rootdir} "
+            "--case-conflict skip"
+        )
+        _, stderr, _ = self.run_cmd(cmd, expected_rc=255)
+        assert "`skip` is not a valid value" in stderr
+
+    @skip_if_windows("Can't rename to same file")
+    def test_s3_express_warn_emits_warning(self):
+        cmd = (
+            f"{self.prefix} s3://bucket--usw2-az1--x-s3 {self.files.rootdir} "
+            "--case-conflict warn"
+        )
+        self.parsed_responses = [
+            self.list_objects_response(['a.txt', 'A.txt']),
+            self.get_object_response(),
+            self.get_object_response(),
+        ]
+
+        _, stderr, _ = self.run_cmd(cmd, expected_rc=0)
+        assert "warning: Recursive copies/moves" in stderr
